package VMOMI::IncompatibleHostForVmReplicationIncompatibleReason;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
